@@ -2,6 +2,17 @@
 
     "use strict";
 
+    /**
+     * Render "name version" as name column
+     */
+    var render_name = function(data, type, row) {
+        var name = data;
+        if (row.version) {
+            name += ' ' + row.version;
+        }
+        return name;
+    };
+
     $(function(){
         $('#browser-table').dataTable({
             "bPaginate": true,
@@ -12,7 +23,7 @@
             "fnRowCallback": Demo.colorRow,
             "aoColumns": [
                 { "mData": "engine" },
-                { "mData": "name" },
+                { "mData": "name", 'mRender': render_name },
                 { "mData": "platform" },
                 { "mData": "engine_version" },
                 { "mData": "css_grade" }
